pw_presubmit: Rename BROKEN to OTHER_CHECKS

Change-Id: I0ee73e23b80b5e8b7a2d0508a97b59c09c27f56d
Reviewed-on: https://pigweed-review.googlesource.com/c/pigweed/pigweed/+/35100
Pigweed-Auto-Submit: Rob Mohr <mohrr@google.com>
Reviewed-by: Wyatt Hepler <hepler@google.com>
Commit-Queue: Auto-Submit <auto-submit@pigweed.google.com.iam.gserviceaccount.com>
diff --git a/pw_presubmit/py/pw_presubmit/pigweed_presubmit.py b/pw_presubmit/py/pw_presubmit/pigweed_presubmit.py
index d015823..8d35b68 100755
--- a/pw_presubmit/py/pw_presubmit/pigweed_presubmit.py
+++ b/pw_presubmit/py/pw_presubmit/pigweed_presubmit.py
@@ -500,8 +500,8 @@
 # Presubmit check programs
 #
 
-BROKEN = (
-    # TODO(pwbug/45): Remove clang-tidy from BROKEN when it passes.
+OTHER_CHECKS = (
+    # TODO(pwbug/45): Remove clang-tidy from OTHER_CHECKS when it passes.
     clang_tidy,
     # Build that attempts to duplicate the build OSS-Fuzz does. Currently
     # failing.
@@ -551,10 +551,10 @@
 )
 
 PROGRAMS = Programs(
-    broken=BROKEN,
-    quick=QUICK,
     full=FULL,
     lintformat=LINTFORMAT,
+    other_checks=OTHER_CHECKS,
+    quick=QUICK,
 )